@@ -4,6 +4,16 @@ from enum import Enum
 
 
 class ChatState(Enum):
+    """
+    Enum of the available chat states
+
+    Values:
+        Starting (str)
+        Composing (str)
+        Paused (str)
+        Deleting (str)
+        Gone (str)
+    """
 
     Starting = 'starting'
     Composing = 'composing'
@@ -26,6 +36,8 @@ class _ChatStateDocument(Document):
 
     @State.setter
     def State(self, chatState):
+        if isinstance(chatState, str):
+            chatState = ChatState(chatState)
         if chatState is not None and not isinstance(chatState, ChatState):
             raise ValueError(
                 '"ChatState" must be a ChatState Model')
@@ -38,5 +50,11 @@ class _ChatStateDocument(Document):
 
 
 class ChatStateDocument(_ChatStateDocument):
+    """
+    Representation of a LIME chat state Document
+
+    Parameters:
+        chatState (ChatState or str)
+    """
 
     Type = MediaType.Parse(_ChatStateDocument.MIME_TYPE)
